# MaFx
## The All In One Math Tool
MaFx is a math tool that can do a lot of things. It can do basic math, algebra, calculus, and more. It is a great tool for students and teachers. It is easy to use and has a simple interface. It is also free and open source

